<?php

declare(strict_types=1);

namespace Drupal\group_context_path_prefix\EventSubscriber;

use Drupal\group_context_path_prefix\SitePrefixManagerInterface;
use Symfony\Component\EventDispatcher\EventSubscriberInterface;
use Symfony\Component\HttpKernel\Event\RequestEvent;
use Symfony\Component\HttpKernel\KernelEvents;

/**
 * Initializes the group path prefix.
 */
final class GroupPathPrefixSubscriber implements EventSubscriberInterface {

  /**
   * Constructs a GroupPathPrefixSubscriber object.
   */
  public function __construct(
    private readonly SitePrefixManagerInterface $sitePrefixManager,
  ) {}

  /**
   * Initializes the group path prefix manager at the beginning of the request.
   *
   * @param \Symfony\Component\HttpKernel\Event\RequestEvent $event
   *   The Event to process.
   */
  public function onKernelRequestGroupPathPrefix(RequestEvent $event): void {
    if ($event->isMainRequest()) {
      $this->initPathPrefix($event->getRequest()->getPathInfo());
    }
  }

  /**
   * Initializes the path prefix in the site prefix manager.
   */
  private function initPathPrefix(string $path): void {
    $this->sitePrefixManager->initPrefixGroup($path);
  }

  /**
   * {@inheritdoc}
   */
  public static function getSubscribedEvents(): array {
    $events = [];
    $events[KernelEvents::REQUEST][] = ['onKernelRequestGroupPathPrefix', 256];
    return $events;
  }

}
